Module arrow2::ffi

source ·
contains FFI bindings to import and export Array via Arrow’s C Data Interface

Modules

Functionality to mmap in-memory data regions.

Structs

ABI-compatible struct for ArrowArray
ABI-compatible struct for ArrowArrayStream.
Implements an iterator of Array consumed from the C stream interface.
ABI-compatible struct for ArrowSchema

Functions

Exports an Box<dyn Array> to the C data interface.
Exports a Field to the C data interface.
Exports an iterator to the C stream interface
Imports an Array from the C data interface.
Imports a Field from the C data interface.