Contains all metadata, such as PhysicalType, DataType, Field and Schema.
Re-exports
pub use crate::types::PrimitiveType;Structs
Represents Arrow’s metadata of a “column”.
Enums
The set of supported logical types in this crate.
the set of valid indices types of a dictionary-encoded Array.
Each type corresponds to a variant of
crate::array::DictionaryArray.Interval units defined in Arrow
The set of physical types: unique in-memory representations of an Arrow array.
A physical type has a one-to-many relationship with a
crate::datatypes::DataType and
a one-to-one mapping to each struct in this crate that implements crate::array::Array.The time units defined in Arrow.
Mode of
DataType::UnionFunctions
support get extension for metadata
Type Definitions
typedef for
Arc<Schema>.