contains the Scalar trait object representing individual items of Arrays,
as well as concrete implementations such as BooleanScalar.
Structs
The
Scalar implementation of binary (Option<Vec<u8>>).The
Scalar implementation of a boolean.The
Scalar implementation of fixed size binary ([Option<Box<[u8]>>]).The scalar equivalent of
FixedSizeListArray. Like FixedSizeListArray, this struct holds a dynamically-typed
Array. The only difference is that this has only one element.The representation of a single entry of a
crate::array::NullArray.A single entry of a
crate::array::StructArray.A single entry of a
crate::array::UnionArray.The implementation of
Scalar for utf8, semantically equivalent to Option<String>.